Flavors manage the sizing for the compute, memory and storage capacity of the instance.

| Name | VCPUS | RAM | Total Disk | Root Disk | Ephemeral Disk | Public |
--- | --- | --- | --- | --- | --- | --- | --- | ---
{$ ::trCtrl.helpText.noneAllocText $}
| {$ ::item.name $} | {$ ::item.vcpus $} | {$ ::item.ram | mb $} | {$ ::item.totalDisk | gb $} | {$ ::item.rootDisk | gb $} | {$ ::item.ephemeralDisk | gb $} | {$ ::item.isPublic | yesno $} |
Impact on your quota

| Name | VCPUS | RAM | Total Disk | Root Disk | Ephemeral Disk | Public |
--- | --- | --- | --- | --- | --- | --- | --- | ---
{$ ::trCtrl.helpText.noneAvailText $}
| {$ ::item.name $} | {$ ::item.vcpus $} | {$ ::item.ram | mb $} | {$ ::item.totalDisk | gb $} | {$ ::item.rootDisk | gb $} | {$ ::item.ephemeralDisk | gb $} | {$ ::item.isPublic | yesno $} |
Impact on your quota